==> zio-aws-ec2_2.12-7.21.15.11-sources.jar: zio/aws/ec2/model/DiskImageDescription.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.ImportManifestUrl
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DiskImageDescription(
    checksum: Optional[String] = Optional.Absent,
    format: Optional[zio.aws.ec2.model.DiskImageFormat] = Optional.Absent,
    importManifestUrl: Optional[ImportManifestUrl] = Optional.Absent,
    size: Optional[Long] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DiskImageDescription = {
    import DiskImageDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DiskImageDescription
      .builder()
      .optionallyWith(checksum.map(value => value: java.lang.String))(
        _.checksum
      )
      .optionallyWith(format.map(value => value.unwrap))(_.format)
      .optionallyWith(
        importManifestUrl.map(value =>
          ImportManifestUrl.unwrap(value): java.lang.String
        )
      )(_.importManifestUrl)
      .optionallyWith(size.map(value => value: java.lang.Long))(_.size)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DiskImageDescription.ReadOnly =
    zio.aws.ec2.model.DiskImageDescription.wrap(buildAwsValue())
}
object DiskImageDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DiskImageDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DiskImageDescription =
      zio.aws.ec2.model.DiskImageDescription(
        checksum.map(value => value),
        format.map(value => value),
        importManifestUrl.map(value => value),
        size.map(value => value)
      )
    def checksum: Optional[String]
    def format: Optional[zio.aws.ec2.model.DiskImageFormat]
    def importManifestUrl: Optional[ImportManifestUrl]
    def size: Optional[Long]
    def getChecksum: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("checksum", checksum)
    def getFormat: ZIO[Any, AwsError, zio.aws.ec2.model.DiskImageFormat] =
      AwsError.unwrapOptionField("format", format)
    def getImportManifestUrl: ZIO[Any, AwsError, ImportManifestUrl] =
      AwsError.unwrapOptionField("importManifestUrl", importManifestUrl)
    def getSize: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("size", size)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DiskImageDescription
  ) extends zio.aws.ec2.model.DiskImageDescription.ReadOnly {
    override val checksum: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.checksum())
      .map(value => value: String)
    override val format: Optional[zio.aws.ec2.model.DiskImageFormat] =
      zio.aws.core.internal
        .optionalFromNullable(impl.format())
        .map(value => zio.aws.ec2.model.DiskImageFormat.wrap(value))
    override val importManifestUrl: Optional[ImportManifestUrl] =
      zio.aws.core.internal
        .optionalFromNullable(impl.importManifestUrl())
        .map(value => zio.aws.ec2.model.primitives.ImportManifestUrl(value))
    override val size: Optional[Long] = zio.aws.core.internal
      .optionalFromNullable(impl.size())
      .map(value => value: Long)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DiskImageDescription
  ): zio.aws.ec2.model.DiskImageDescription.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.104.3-sources.jar: zio/aws/ec2/model/DiskImageDescription.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DiskImageDescription(
    checksum: Option[String] = None,
    format: Option[zio.aws.ec2.model.DiskImageFormat] = None,
    importManifestUrl: Option[String] = None,
    size: Option[Long] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DiskImageDescription = {
    import DiskImageDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DiskImageDescription
      .builder()
      .optionallyWith(checksum.map(value => value: java.lang.String))(
        _.checksum
      )
      .optionallyWith(format.map(value => value.unwrap))(_.format)
      .optionallyWith(importManifestUrl.map(value => value: java.lang.String))(
        _.importManifestUrl
      )
      .optionallyWith(size.map(value => value: java.lang.Long))(_.size)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DiskImageDescription.ReadOnly =
    zio.aws.ec2.model.DiskImageDescription.wrap(buildAwsValue())
}
object DiskImageDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DiskImageDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DiskImageDescription =
      zio.aws.ec2.model.DiskImageDescription(
        checksum.map(value => value),
        format.map(value => value),
        importManifestUrl.map(value => value),
        size.map(value => value)
      )
    def checksum: Option[String]
    def format: Option[zio.aws.ec2.model.DiskImageFormat]
    def importManifestUrl: Option[String]
    def size: Option[Long]
    def getChecksum: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("checksum", checksum)
    def getFormat: ZIO[Any, AwsError, zio.aws.ec2.model.DiskImageFormat] =
      AwsError.unwrapOptionField("format", format)
    def getImportManifestUrl: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("importManifestUrl", importManifestUrl)
    def getSize: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("size", size)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DiskImageDescription
  ) extends zio.aws.ec2.model.DiskImageDescription.ReadOnly {
    override val checksum: Option[String] =
      scala.Option(impl.checksum()).map(value => value: String)
    override val format: Option[zio.aws.ec2.model.DiskImageFormat] = scala
      .Option(impl.format())
      .map(value => zio.aws.ec2.model.DiskImageFormat.wrap(value))
    override val importManifestUrl: Option[String] =
      scala.Option(impl.importManifestUrl()).map(value => value: String)
    override val size: Option[Long] =
      scala.Option(impl.size()).map(value => value: Long)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DiskImageDescription
  ): zio.aws.ec2.model.DiskImageDescription.ReadOnly = new Wrapper(impl)
}
